// 
// Patron pour la generation d'une classe derivee dans ROOT
// FBooklet derive de TNamed
// 
 
#ifndef FBooklet_h 
#define FBooklet_h 
 
#include "Riostream.h" 
#include "TNamed.h" 
#include "FPage.h"

using namespace std;
 
class FBooklet : public TNamed { 
 
   protected:
	TList listOfPages;
	Int_t currentPage;
	FPageLayout *currentPageLayout;
  
   protected: 
        virtual void Init(void);       // initialisation 
 
   public:	 
   	FBooklet(void);    // constructeur par defaut 
	FBooklet(const FBooklet &ap); // constructeur par copie 
	
	~FBooklet(void);		// desctructeur; 
	 
#if ROOT_VERSION_CODE >= ROOT_VERSION(3,4,0)
   	virtual void Copy(TObject & obj) const;
#else
   	virtual void Copy(TObject & obj);
#endif
	FBooklet& operator = (const FBooklet &hp); // operateur = 
 
	virtual const TList *GetListOfPages(void)
	        {return &listOfPages;}
	virtual const Char_t *GetPageName(Int_t pageNumber);
	virtual void AddPage(FPage *page){listOfPages.Add(page);}
	virtual FPage *GetPage(Int_t pageNumber)
	             {return (FPage *)listOfPages.At(pageNumber);}
	virtual void RemovePage(Int_t pageNumber=0)
	             {listOfPages.RemoveAt(pageNumber);}
	virtual void RemovePage(const Char_t *pageName);
	virtual void RemovePage(FPage *page)
	             {listOfPages.Remove(page);}
	virtual Int_t GetCurrentPageNumber(void)
	             {return currentPage;}

	virtual void DisplayCurrentPage(TPad *p=(TPad *)gPad);
	virtual void DisplayNextPage(TPad *p=(TPad *)gPad);
	virtual void DisplayPreviousPage(TPad *p=(TPad *)gPad);
	virtual void DisplayPage(const Char_t *pageName,TPad *p=(TPad *)gPad);
	 
	virtual void WriteInFile(ofstream &fout);
 	virtual void ReadInFile(ifstream &fin,TList *lOfLayout, TList *listOfHistos);
	
 	virtual void    ls(Option_t *option="") const;

    ClassDef(FBooklet,1)
 
}; 
 
#endif 
 
