// 
// Patron pour la generation d'une classe derivee dans ROOT
// FHistAtt derive de TNamed
// 
 
#ifndef FHistAtt_h 
#define FHistAtt_h 
 
#include "Riostream.h" 
#include "TList.h" 
#include "TH1.h" 
#include "FParam.h" 
#include "FCondition.h" 
#include "TList.h" 
#include "TClass.h"
#include "TString.h" 
#include "TApplication.h" 

class FEventProcessor; 
class FGenericName; 
 
class FHistAtt  { 

   
   protected:
	TH1		*histo;
	TList		*listOfParams; //!
	FCondition 	*condition;
	FParam	 	*weightParam;
   	Int_t 		nbValuesToFill;
	Bool_t		actif;
	Color_t		frameColor;
   
   protected: 
        virtual void Init(void);       // initialisation 
	virtual Int_t ComputeNbValues(Int_t nbv,FParam *p);
	virtual void SetNbValues(Int_t nbv){nbValuesToFill=nbv;}
 
   public:	 
   	FHistAtt(void);    // constructeur par defaut 
	FHistAtt(const FHistAtt &ap); // constructeur par copie 
	
	virtual ~FHistAtt(void);		// desctructeur; 
	 
#if ROOT_VERSION_CODE >= ROOT_VERSION(3,4,0)
   	virtual void CopyHistAtt(FHistAtt & obj) const;
#else
   	virtual void CopyHistAtt(FHistAtt & obj);
#endif
	FHistAtt& operator = (const FHistAtt &hp); // operateur = 

	virtual void AddParam(FParam *p)
	  {listOfParams->Add(p);
	  if(!p->GetLinkedObjects()->FindObject(histo))
	   p->GetLinkedObjects()->Add(histo);}
	virtual void AddParamAt(Int_t i,FParam *p)
	  {listOfParams->AddAt(p,i);
	  if(!p->GetLinkedObjects()->FindObject(histo))
	   p->GetLinkedObjects()->Add(histo);}
	virtual void RemoveParams(void);
	virtual void RemoveParamAt(Int_t i);
	virtual TH1 *GetHisto(void){return 0;}
	virtual void ResetParams(void);
	virtual TList *GetListOfParams(void){return listOfParams;}
	virtual void FillHist(Stat_t w=1.);
	virtual void ResetCondition(void);
	virtual void SetCondition(FCondition *c=0);
 	virtual FCondition *GetCondition() {return condition;}
	virtual void ResetWeight(void);
	virtual void SetWeight(FParam *p=0);
 	virtual FParam *GetWeight() {return weightParam;}

 	virtual void WriteInFile(ofstream &fout);
 	virtual Bool_t  ReadInFile(ifstream &fin, TList *lop);
	virtual TList *GenericBuilding(TList *lop=0,TList *los=0,
				      FGenericName *name=0,
				      FGenericName *title=0,
				      FGenericName *paramX=0,
				      Int_t nx=0,Double_t xmin=0.,Double_t xmax=0.,
				      FGenericName *paramY=0,
				      Int_t ny=0,Double_t ymin=0.,Double_t ymax=0.,
				      FGenericName *cond=0){return 0;}
 
   	virtual void ResetToInit(Option_t *option="")
	 {if(histo) histo->Reset();}
	 
	virtual void Activate(Bool_t act=kTRUE) {actif=act;} 
	virtual void ToggleActivate(Int_t val=1);
	virtual Bool_t IsActivated(void) {return actif;}
	virtual void SetCanRebin(Bool_t reb=kTRUE);
	virtual void ToggleCanRebin(Int_t val=1);
#if ROOT_VERSION_CODE < ROOT_VERSION(6,0,0)
	virtual Bool_t CanRebin(void) 
			{return histo->TestBit(TH1::kCanRebin);}
#else
	virtual Bool_t CanRebin(void) 
			{    
		        Bool_t canExtend = histo->GetXaxis()->CanExtend();
                        if (histo->GetDimension() > 1) 
				canExtend |= histo->GetYaxis()->CanExtend();
                        if (histo->GetDimension() > 2) 
				canExtend |= histo->GetZaxis()->CanExtend();
			return canExtend;
			}
#endif	
	virtual void PaintHistAtt(Option_t *option="");
 

    ClassDef(FHistAtt,1)
 
}; 
 
#endif 
 
