// 
// Patron pour la generation d'une classe derivee dans ROOT
// FOscilloH1Att derive de FH1Att
// 
 
#ifndef FOscilloH1Att_h 
#define FOscilloH1Att_h 
 
#include "FH1Att.h" 
#include "TGraph.h" 
#include <vector>
 
class FOscilloH1Att : public FH1Att { 
 
   protected:
   	Double_t timeStep;
   	Double_t voltStep;
   	Double_t time0;
   	TString legX;
   	TString legY;
	
	Int_t	         nPersist;  // Parametre de persistance
	vector<TGraph *> vPersist;  // vecteur des graphes de persistance
	Int_t		 curIndex;
	// Ajout de variables pour la gestion d'un nombre de points variable
	// Pour les Oscillos etles echantillons (Samples) du SAMPLER
	Int_t		 nbSamplesToDisplay;
	Int_t		 nbOscToDisplay;

   protected: 
        virtual void Init(void);       // initialisation 

        // Gestion des TGraphs utilises pour la Persistance sur les Oscillos	
	virtual void RemoveGraphs(void); // Enleve tous les graphes
	virtual void ResetGraphs(void);  // Reconstruit tous les graphes
 
   public:	 
   	FOscilloH1Att(void);    // constructeur par defaut 
	FOscilloH1Att(const FOscilloH1Att &ap); // constructeur par copie 
	
	~FOscilloH1Att(void);		// desctructeur; 
	 
#if ROOT_VERSION_CODE >= ROOT_VERSION(3,4,0)
   	virtual void CopyHistAtt(FH1Att & obj) const;
#else
   	virtual void CopyHistAtt(FH1Att & obj);
#endif
	FOscilloH1Att& operator = (const FOscilloH1Att &hp); // operateur = 
 
	virtual void FillHist(Stat_t w=1.);
	virtual void SetParamX(FParam *p);

 	virtual void WriteInFile(ofstream &fout);
 	virtual Bool_t  ReadInFile(ifstream &fin, TList *lop);
	virtual TList *GenericBuilding(TList *lop=0,TList *los=0,
				      FGenericName *name=0,
				      FGenericName *title=0,
				      FGenericName *paramX=0,
				      Int_t nx=0,Double_t xmin=0.,Double_t xmax=0.,
				      FGenericName *paramY=0,
				      Int_t ny=0,Double_t ymin=0.,Double_t ymax=0.,
				      FGenericName *cond=0);
        
	virtual void SetNbOscToDisplay(Int_t n){nbOscToDisplay=n;} // MAJ du nb de points Oscillo a afficher
	virtual void SetPersistance(Int_t p=0);
	virtual Int_t GetPersistance(void) {return nPersist;}
	virtual void SetT0(Double_t t);
	virtual Double_t GetT0(void){return time0;}
	virtual void SetTimeStep(Double_t t);
	virtual Double_t GetTimeStep(void){return timeStep;}
	virtual void SetVoltStep(Double_t v);
	virtual Double_t GetVoltStep(void){return voltStep;}
	virtual void SetLegX(TString lx="xUnit");
	virtual void SetLegY(TString lx="yUnit");
	
    ClassDef(FOscilloH1Att,1)
 
}; 
 
#endif 
 
